
JOURNAL_CANTDO_LIST = [
    'Nat Monspel Ser Bot',
    'Nat Prod Lett',
    'Nat Hist',
    'Nat Mus',
    'Nat Syst'
    'Nat Resour Forum',
    'Nat Law Forum',
    'Nat Resour J',
    'Zhonghua Yi Xue Yi Chuan Xue Za Zhi',
]

